mondrian
========

Mondrian helps you paint your standard python logger.

Just use:

.. code-block:: python

    import logging
    import mondrian

    logger = mondrian.getLogger()
    logger.setLevel(logging.INFO)

Done.

